@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,24 +28,6 @@
 
 /* This code comes from gnome vfs: */
 
-static gboolean
-is_uri_relative (const char *uri)
-{
-	const char *current;
-
-	/* RFC 2396 section 3.1 */
-	for (current = uri ; 
-		*current
-		&& 	((*current >= 'a' && *current <= 'z')
-			 || (*current >= 'A' && *current <= 'Z')
-			 || (*current >= '0' && *current <= '9')
-			 || ('-' == *current)
-			 || ('+' == *current)
-			 || ('.' == *current)) ;
-	     current++);
-
-	return  !(':' == *current);
-}
 
 
 /*
@@ -131,18 +113,36 @@ remove_internal_relative_components (char *uri_current)
 	
 }
 
+gboolean
+yelp_util_is_url_relative (const char *url)
+{
+	const char *current;
+
+	/* RFC 2396 section 3.1 */
+	for (current = url ; 
+		*current
+		&& 	((*current >= 'a' && *current <= 'z')
+			 || (*current >= 'A' && *current <= 'Z')
+			 || (*current >= '0' && *current <= '9')
+			 || ('-' == *current)
+			 || ('+' == *current)
+			 || ('.' == *current)) ;
+	     current++);
+
+	return  !(':' == *current);
+}
 
 /* If I had known this relative uri code would have ended up this long, I would
  * have done it a different way
  */
 char *
-yelp_util_resolve_relative_uri (const char *base_uri,
-				const char *uri)
+yelp_util_resolve_relative_url (const char *base_uri,
+				const char *url)
 {
 	char *result = NULL;
 
-	g_return_val_if_fail (base_uri != NULL, g_strdup (uri));
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (url != NULL, NULL);
+	g_return_val_if_fail (base_uri != NULL, g_strdup (url));
 
 	/* See section 5.2 in RFC 2396 */
 
@@ -151,10 +151,10 @@ yelp_util_resolve_relative_uri (const char *base_uri,
 	 * functionality differs from what Mozilla itself would do.
 	 */
 
-	if (uri[0] == '?') {
-		result = g_strconcat (base_uri, uri, NULL);
+	if (url[0] == '?' || url[0] == '#') {
+		result = g_strconcat (base_uri, url, NULL);
 	}
-	else if (is_uri_relative (uri)) {
+	else if (yelp_util_is_url_relative (url)) {
 		char *mutable_base_uri;
 		char *mutable_uri;
 
@@ -170,7 +170,7 @@ yelp_util_resolve_relative_uri (const char *base_uri,
 		mutable_base_uri = g_malloc(strlen(base_uri)+2);
 		strcpy (mutable_base_uri, base_uri);
 		
-		uri_current = mutable_uri = g_strdup (uri);
+		uri_current = mutable_uri = g_strdup (url);
 
 		/* Chew off Fragment and Query from the base_url */
 
@@ -270,7 +270,7 @@ yelp_util_resolve_relative_uri (const char *base_uri,
 		g_free (mutable_uri); 
 
 	} else {
-		result = g_strdup (uri);
+		result = g_strdup (url);
 	}
 	
 	return result;
@@ -366,14 +366,14 @@ yelp_util_string_path_to_node (const char *string_path,
 GNode *
 yelp_util_decompose_path_url (GNode       *root,
 			      const char  *path_url,
-			      gchar      **embedded_url)
+			      YelpURI    **embedded_uri)
 {
 	const gchar *first_part;
 	const gchar *second_part;
 	gchar       *path;
 	GNode       *res;
 
-	*embedded_url = NULL;
+	*embedded_uri = NULL;
 	
 	if (strncmp (path_url, "path:", 5) != 0) {
 		return NULL;
@@ -393,7 +393,7 @@ yelp_util_decompose_path_url (GNode       *root,
 	g_free (path);
 
 	if (second_part) {
-		*embedded_url = g_strdup (second_part);
+		*embedded_uri = yelp_uri_new (second_part);
 	}
 	
 	return res;
@@ -471,7 +471,7 @@ yelp_util_find_node_from_name (GNode *doc_tree, const gchar *name)
 }
 
 static gboolean
-tree_find_node_uri (GNode *node, const gchar *uri)
+tree_find_node_uri (GNode *node, YelpURI *uri)
 {
 	YelpSection *section;
 	
@@ -481,16 +481,16 @@ tree_find_node_uri (GNode *node, const gchar *uri)
 		return FALSE;
 	}
 	
-	if (!g_ascii_strcasecmp (uri, section->uri)) {
+	if (yelp_uri_equal (uri, section->uri)) {
 		found_node = node;
 		return TRUE;
 	}
-	
+
 	return FALSE;
 }
 
 GNode *
-yelp_util_find_node_from_uri (GNode *doc_tree, const gchar *uri)
+yelp_util_find_node_from_uri (GNode *doc_tree, YelpURI *uri)
 {
 	found_node = NULL;
 	
@@ -498,43 +498,55 @@ yelp_util_find_node_from_uri (GNode *doc_tree, const gchar *uri)
 			 G_TRAVERSE_ALL,
 			 -1,
 			 (GNodeTraverseFunc) tree_find_node_uri,
-			 (gchar *) uri);
+			 uri);
 	    
 	return found_node;
 }
 
 gchar *
-yelp_util_extract_docpath_from_uri (const gchar *str_uri)
+yelp_util_extract_docpath_from_uri (const gchar *inc_uri)
 {
 	GnomeVFSURI *uri;
+	gchar       *str_uri;
 	gchar       *transformed_uri;
 	gchar       *docpath = NULL;
-	gchar       *extension;
+	const gchar *ch = NULL;
+	
+	if ((ch = strchr (inc_uri, '?')) || (ch = strchr (inc_uri, '#'))) {
+		str_uri = g_strndup (inc_uri, ch - inc_uri);
+	} else {
+		str_uri = g_strdup (inc_uri);
+	}
 
 	if (!strncmp (str_uri, "man:", 4)) {
-		return g_strdup (str_uri + 4);
+		return str_uri;
 	}
 	else if (!strncmp (str_uri, "info:", 5)) {
-		return g_strdup (str_uri + 5);
+		return str_uri;
 	} 
 	else if (strncmp (str_uri, "ghelp:", 6)) {
 		/* Strange uri, just return the same string */
-		return g_strdup (str_uri);
+		return str_uri;
 	}
 
-	if ((extension = strstr (str_uri, ".xml"))) {
-		const gchar *str;
+	if (strstr (str_uri, ".xml") || strstr (str_uri, ".sgml")) {
+		gchar *str;
+
 		str = str_uri + 6;
-		/* This means we have a ghelp-uri with full path */
-		docpath = g_strndup (str, extension + 4 - str);
-	}
-	else if ((extension = strstr (str_uri, ".sgml"))) {
-		const gchar *str;
-		str = str_uri + 6;
-		docpath = g_strndup (str, extension + 5 - str);
-	} else {
-		/* URI not a fullpath URI, let the GnomeVFS help module 
-		   calculate the full URI */
+		uri = gnome_vfs_uri_new (str);
+		str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+
+		/* strlen ("file://") == 7 */
+		if (!strncmp (str, "file://", 7)) {
+			docpath = g_strdup (str + 7);
+		}
+		
+		g_free (str);
+	} 
+
+	if (!docpath) {
+		/* OK, nothing else have worked, try to get the docpath by *
+		 * using the gnome-vfs-module                              */
 		uri = gnome_vfs_uri_new (str_uri);
 		
 		if (uri) {
@@ -559,20 +571,24 @@ yelp_util_extract_docpath_from_uri (const gchar *str_uri)
 								     NULL);
 			}
 		} else {
-			return NULL;
+			docpath = NULL;
 		}
 	}
 
+	g_free (str_uri);
+
+/* 	g_print ("Returning docpath: %s\n", docpath) */
+	
 	return docpath;
 }
 
 gchar *
 yelp_util_split_uri (const gchar *uri, gchar **anchor)
 {
-	gchar *str;
-	gchar *ret = NULL;
-	gchar *anchor_ptr;
-	gint   len;
+	gchar       *str;
+	gchar       *ret = NULL;
+	const gchar *anchor_ptr;
+	gint         len;
 	
 	anchor_ptr = yelp_util_find_anchor_in_uri (uri);
 	
@@ -612,3 +628,4 @@ yelp_util_find_anchor_in_uri (const gchar *str_uri)
 
 	return NULL;
 }
+
