@@ -24,8 +24,18 @@
 #include <config.h>
 #endif
 
-#include <libgnome/gnome-i18n.h>
+#include <atk/atk.h>
+#include <gtk/gtkaccessible.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtktreeview.h>
+#include <gtk/gtktreeselection.h>
+#include <libgnome/gnome-i18n.h>
 #include <string.h>
 
 #include "yelp-index-model.h"
@@ -33,13 +43,14 @@
 #include "yelp-marshal.h"
 #include "yelp-view-index.h"
 
+#define d(x)
+
 static void     yvi_init                       (YelpViewIndex       *view);
 static void     yvi_class_init                 (YelpViewIndexClass  *klass);
 static void     yvi_index_selection_changed_cb (GtkTreeSelection    *selection,
 						YelpViewIndex       *content);
-static void     yvi_html_url_selected_cb       (YelpHtml            *html,
-						char                *url,
-						char                *base_url,
+static void     yvi_html_uri_selected_cb       (YelpHtml            *html,
+						YelpURI             *uri,
 						gboolean             handled,
 						YelpViewIndex       *view);
 static void     yvi_entry_changed_cb           (GtkEntry            *entry,
@@ -66,7 +77,7 @@ struct _YelpViewIndexPriv {
 	GtkWidget      *entry;
 	
 	/* Html view */
-	GtkWidget      *html_view;
+	YelpHtml       *html_view;
 
 	GCompletion    *completion;
 
@@ -75,7 +86,7 @@ struct _YelpViewIndexPriv {
 };
 
 enum {
-	URL_SELECTED,
+	URI_SELECTED,
 	LAST_SIGNAL
 };
 
@@ -131,24 +142,24 @@ yvi_init (YelpViewIndex *view)
 
 	priv->html_view = yelp_html_new ();
 	
-	g_signal_connect (priv->html_view, "url_selected",
-			  G_CALLBACK (yvi_html_url_selected_cb),
+	g_signal_connect (priv->html_view, "uri_selected",
+			  G_CALLBACK (yvi_html_uri_selected_cb),
 			  view);
 }
 
 static void
 yvi_class_init (YelpViewIndexClass *klass)
 {
-	signals[URL_SELECTED] =
-		g_signal_new ("url_selected",
+	signals[URI_SELECTED] =
+		g_signal_new ("uri_selected",
 			      G_TYPE_FROM_CLASS (klass),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (YelpViewIndexClass,
-					       url_selected),
+					       uri_selected),
 			      NULL, NULL,
-			      yelp_marshal_VOID__STRING_STRING_BOOLEAN,
+			      yelp_marshal_VOID__POINTER_BOOLEAN,
 			      G_TYPE_NONE,
-			      3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
+			      2, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 }
 
 static void
@@ -169,28 +180,26 @@ yvi_index_selection_changed_cb (GtkTreeSelection *selection,
 				    YELP_INDEX_MODEL_COL_SECTION, &section,
 				    -1);
 
-  		g_signal_emit (view, signals[URL_SELECTED], 0,
- 			       section->reference, section->uri, FALSE);
+		d(g_print ("Index View: selection changed: %s\n", 
+			   yelp_uri_to_string (section->uri)));
+		
+  		g_signal_emit (view, signals[URI_SELECTED], 0,
+ 			       section->uri, FALSE);
 	}
 }
 
 static void
-yvi_html_url_selected_cb (YelpHtml      *html,
-			  char          *url,
-			  char          *base_url,
+yvi_html_uri_selected_cb (YelpHtml      *html, 
+			  YelpURI       *uri, 
 			  gboolean       handled,
 			  YelpViewIndex *view)
 {
-	gchar *real_base_url;
-	
 	g_return_if_fail (YELP_IS_VIEW_INDEX (view));
 
-	real_base_url = g_strconcat ("index:", base_url, NULL);
+	d(g_print ("Index View: uri selected: %s\n", 
+		   yelp_uri_to_string (uri)));
 
-	g_signal_emit (view, signals[URL_SELECTED], 0, 
-		       url, real_base_url, handled);
-
-	g_free (real_base_url);
+	g_signal_emit (view, signals[URI_SELECTED], 0, uri, handled);
 }
 
 static void
@@ -326,7 +335,7 @@ yelp_view_index_new (GList *index)
 	
 	label = gtk_label_new (_("Search for:"));
 
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
 
 	priv->entry = gtk_entry_new ();
 
@@ -349,11 +358,16 @@ yelp_view_index_new (GList *index)
 	gtk_box_pack_start (GTK_BOX (box), hbox, 
 			    FALSE, FALSE, 0);
 
+	frame = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
+	
         list_sw = gtk_scrolled_window_new (NULL, NULL);
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (list_sw),
                                         GTK_POLICY_AUTOMATIC, 
                                         GTK_POLICY_AUTOMATIC);
 
+	gtk_container_add (GTK_CONTAINER (frame), list_sw);
+	
 	gtk_tree_view_insert_column_with_attributes (
 		GTK_TREE_VIEW (priv->index_view), -1,
 		_("Section"), gtk_cell_renderer_text_new (),
@@ -372,7 +386,7 @@ yelp_view_index_new (GList *index)
 	
 	gtk_container_add (GTK_CONTAINER (list_sw), priv->index_view);
 
-	gtk_box_pack_end_defaults (GTK_BOX (box), list_sw);
+	gtk_box_pack_end_defaults (GTK_BOX (box), frame);
 
         /* Setup the Html view */
  	html_sw = gtk_scrolled_window_new (NULL, NULL);
@@ -383,7 +397,8 @@ yelp_view_index_new (GList *index)
 	gtk_container_add (GTK_CONTAINER (frame), html_sw);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	
-        gtk_container_add (GTK_CONTAINER (html_sw), priv->html_view);
+        gtk_container_add (GTK_CONTAINER (html_sw), 
+			   yelp_html_get_widget (YELP_HTML (priv->html_view)));
 
 	/* Add the tree and html view to the paned */
 	gtk_paned_add1 (GTK_PANED (view), box);
@@ -397,20 +412,19 @@ yelp_view_index_new (GList *index)
 }
 
 void
-yelp_view_index_show_uri (YelpViewIndex *view, const gchar *uri)
+yelp_view_index_show_uri (YelpViewIndex  *view,
+			  YelpURI        *uri,
+			  GError        **error)
 {
 	YelpViewIndexPriv *priv;
-	const gchar       *real_uri;
 
 	g_return_if_fail (YELP_IS_VIEW_INDEX (view));
 	g_return_if_fail (uri != NULL);
-	g_return_if_fail (strncmp (uri, "index:", 6) == 0);
 	
 	priv = view->priv;
 
-	real_uri = uri + 6;
-
-	yelp_html_open_uri (YELP_HTML (priv->html_view), real_uri, NULL);
+	/* FIXME: Handle the GError */
+	yelp_html_open_uri (priv->html_view, uri, error);
 }
 
 /**
